@@ -120,8 +120,9 @@ struct _GstVaapiDisplayPrivate
   guint height_mm;
   guint par_n;
   guint par_d;
-  GArray *decoders;
-  GArray *encoders;
+  GPtrArray *decoders; /* ref element in codecs */
+  GPtrArray *encoders; /* ref element in codecs */
+  GArray *codecs;
   GArray *image_formats;
   GArray *subpicture_formats;
   GArray *properties;
@@ -130,6 +131,7 @@ struct _GstVaapiDisplayPrivate
   guint has_vpp:1;
   guint has_profiles:1;
   guint got_scrres:1;
+  guint driver_quirks;
 };
 
 /**
