@@ -105,6 +105,44 @@ static const struct xdg_wm_base_listener xdg_wm_base_listener = {
   handle_xdg_wm_base_ping
 };
 
+static void
+dmabuf_format (void *data, struct zwp_linux_dmabuf_v1 *zwp_linux_dmabuf,
+    uint32_t format)
+{
+}
+
+static void
+dmabuf_modifier (void *data, struct zwp_linux_dmabuf_v1 *zwp_linux_dmabuf,
+    uint32_t format, uint32_t modifier_hi, uint32_t modifier_lo)
+{
+  GstVaapiDisplayWaylandPrivate *const priv = data;
+  GstDRMFormat drm_format = {
+    .format = format,
+    .modifier = (guint64) modifier_hi << 32 | modifier_lo
+  };
+
+  if (gst_vaapi_video_format_from_drm_format (format) ==
+      GST_VIDEO_FORMAT_UNKNOWN) {
+    GST_LOG ("ignoring unknown format 0x%x with modifier 0x%" G_GINT64_MODIFIER
+        "x", format, drm_format.modifier);
+    return;
+  }
+
+  GST_LOG ("got format 0x%x (%s) with modifier 0x%" G_GINT64_MODIFIER "x",
+      format, gst_video_format_to_string (gst_vaapi_video_format_from_drm_format
+          (format)), drm_format.modifier);
+
+  g_mutex_lock (&priv->dmabuf_formats_lock);
+  g_array_append_val (priv->dmabuf_formats, drm_format);
+  g_mutex_unlock (&priv->dmabuf_formats_lock);
+}
+
+static const struct zwp_linux_dmabuf_v1_listener dmabuf_listener = {
+  dmabuf_format,
+  dmabuf_modifier,
+};
+
+
 static void
 registry_handle_global (void *data,
     struct wl_registry *registry,
@@ -115,6 +153,9 @@ registry_handle_global (void *data,
   if (strcmp (interface, "wl_compositor") == 0)
     priv->compositor =
         wl_registry_bind (registry, id, &wl_compositor_interface, 1);
+  else if (strcmp (interface, "wl_subcompositor") == 0)
+    priv->subcompositor =
+        wl_registry_bind (registry, id, &wl_subcompositor_interface, 1);
   else if (strcmp (interface, "wl_shell") == 0)
     priv->wl_shell = wl_registry_bind (registry, id, &wl_shell_interface, 1);
   else if (strcmp (interface, "xdg_wm_base") == 0) {
@@ -122,8 +163,14 @@ registry_handle_global (void *data,
         wl_registry_bind (registry, id, &xdg_wm_base_interface, 1);
     xdg_wm_base_add_listener (priv->xdg_wm_base, &xdg_wm_base_listener, priv);
   } else if (strcmp (interface, "wl_output") == 0) {
-    priv->output = wl_registry_bind (registry, id, &wl_output_interface, 1);
-    wl_output_add_listener (priv->output, &output_listener, priv);
+    if (!priv->output) {
+      priv->output = wl_registry_bind (registry, id, &wl_output_interface, 1);
+      wl_output_add_listener (priv->output, &output_listener, priv);
+    }
+  } else if (strcmp (interface, "zwp_linux_dmabuf_v1") == 0) {
+    priv->dmabuf =
+        wl_registry_bind (registry, id, &zwp_linux_dmabuf_v1_interface, 3);
+    zwp_linux_dmabuf_v1_add_listener (priv->dmabuf, &dmabuf_listener, priv);
   }
 }
 
@@ -212,9 +259,14 @@ gst_vaapi_display_wayland_close_display (GstVaapiDisplay * display)
   g_clear_pointer (&priv->output, wl_output_destroy);
   g_clear_pointer (&priv->wl_shell, wl_shell_destroy);
   g_clear_pointer (&priv->xdg_wm_base, xdg_wm_base_destroy);
+  g_clear_pointer (&priv->subcompositor, wl_subcompositor_destroy);
   g_clear_pointer (&priv->compositor, wl_compositor_destroy);
   g_clear_pointer (&priv->registry, wl_registry_destroy);
 
+  g_mutex_lock (&priv->dmabuf_formats_lock);
+  g_array_unref (priv->dmabuf_formats);
+  g_mutex_unlock (&priv->dmabuf_formats_lock);
+
   if (priv->wl_display) {
     if (!priv->use_foreign_display)
       wl_display_disconnect (priv->wl_display);
@@ -292,6 +344,8 @@ gst_vaapi_display_wayland_init (GstVaapiDisplayWayland * display)
 
   display->priv = priv;
   priv->event_fd = -1;
+  priv->dmabuf_formats = g_array_new (FALSE, FALSE, sizeof (GstDRMFormat));
+  g_mutex_init (&priv->dmabuf_formats_lock);
 }
 
 static void
@@ -342,7 +396,7 @@ gst_vaapi_display_wayland_new (const gchar * display_name)
  * Return value: a newly allocated #GstVaapiDisplay object
  */
 GstVaapiDisplay *
-gst_vaapi_display_wayland_new_with_display (struct wl_display * wl_display)
+gst_vaapi_display_wayland_new_with_display (struct wl_display *wl_display)
 {
   GstVaapiDisplay *display;
 
@@ -369,7 +423,7 @@ gst_vaapi_display_wayland_new_with_display (struct wl_display * wl_display)
 
 GstVaapiDisplay *
 gst_vaapi_display_wayland_new_with_va_display (VADisplay va_display,
-    struct wl_display * wl_display)
+    struct wl_display *wl_display)
 {
   GstVaapiDisplay *display;
   GstVaapiDisplayInfo info = {
