@@ -26,6 +26,7 @@
 #define GST_VAAPI_UTILS_H
 
 #include <glib.h>
+#include <gst/video/video.h>
 #include <va/va.h>
 
 /** calls vaInitialize() redirecting the logging mechanism */
@@ -54,6 +55,12 @@ gboolean
 vaapi_create_buffer (VADisplay dpy, VAContextID ctx, int type, guint size,
     gconstpointer data, VABufferID * buf_id, gpointer * mapped_data);
 
+G_GNUC_INTERNAL
+gboolean
+vaapi_create_n_elements_buffer (VADisplay dpy, VAContextID ctx, int type,
+    guint size, gconstpointer data, VABufferID * buf_id, gpointer * mapped_data,
+    int num_elements);
+
 /** Destroy VA buffer */
 G_GNUC_INTERNAL
 void
@@ -147,4 +154,25 @@ G_GNUC_INTERNAL
 guint
 to_GstVaapiScaleMethod (guint flags);
 
+G_GNUC_INTERNAL
+void
+from_GstVideoOrientationMethod (guint value, guint * va_mirror,
+    guint * va_rotation);
+
+G_GNUC_INTERNAL
+guint
+from_GstVaapiBufferMemoryType (guint type);
+
+G_GNUC_INTERNAL
+guint
+to_GstVaapiBufferMemoryType (guint va_type);
+
+G_GNUC_INTERNAL
+guint
+from_GstVideoColorimetry (const GstVideoColorimetry *const colorimetry);
+
+G_GNUC_INTERNAL
+guint
+from_GstVideoColorRange (const GstVideoColorRange value);
+
 #endif /* GST_VAAPI_UTILS_H */
