@@ -25,6 +25,9 @@
 #include "gstvaapicompat.h"
 #include "gstvaapiutils_h264_priv.h"
 
+#define DEBUG 1
+#include "gstvaapidebug.h"
+
 struct map
 {
   guint value;
@@ -70,6 +73,9 @@ static const struct map gst_vaapi_h264_level_map[] = {
   { GST_VAAPI_LEVEL_H264_L5,    "5"     },
   { GST_VAAPI_LEVEL_H264_L5_1,  "5.1"   },
   { GST_VAAPI_LEVEL_H264_L5_2,  "5.2"   },
+  { GST_VAAPI_LEVEL_H264_L6,    "6"     },
+  { GST_VAAPI_LEVEL_H264_L6_1,  "6.1"   },
+  { GST_VAAPI_LEVEL_H264_L6_2,  "6.2"   },
   { 0, NULL }
 /* *INDENT-ON* */
 };
@@ -95,6 +101,9 @@ static const GstVaapiH264LevelLimits gst_vaapi_h264_level_limits[] = {
   { GST_VAAPI_LEVEL_H264_L5,    50,   589824,  22080, 110400, 135000, 135000, 2 },
   { GST_VAAPI_LEVEL_H264_L5_1,  51,   983040,  36864, 184320, 240000, 240000, 2 },
   { GST_VAAPI_LEVEL_H264_L5_2,  52,  2073600,  36864, 184320, 240000, 240000, 2 },
+  { GST_VAAPI_LEVEL_H264_L6,    60,  4177920, 139264, 696320, 240000, 240000, 2 },
+  { GST_VAAPI_LEVEL_H264_L6_1,  61,  8355840, 139264, 696320, 480000, 480000, 2 },
+  { GST_VAAPI_LEVEL_H264_L6_2,  62, 16711680, 139264, 696320, 800000, 800000, 2 },
   { 0, }
 };
 /* *INDENT-ON* */
@@ -179,7 +188,7 @@ gst_vaapi_utils_h264_get_profile (guint8 profile_idc)
       profile = GST_VAAPI_PROFILE_H264_STEREO_HIGH;
       break;
     default:
-      g_debug ("unsupported profile_idc value");
+      GST_DEBUG ("unsupported profile_idc value");
       profile = GST_VAAPI_PROFILE_UNKNOWN;
       break;
   }
@@ -228,7 +237,7 @@ gst_vaapi_utils_h264_get_profile_idc (GstVaapiProfile profile)
       profile_idc = GST_H264_PROFILE_STEREO_HIGH;
       break;
     default:
-      g_debug ("unsupported GstVaapiProfile value");
+      GST_DEBUG ("unsupported GstVaapiProfile value");
       profile_idc = 0;
       break;
   }
@@ -268,7 +277,7 @@ gst_vaapi_utils_h264_get_level (guint8 level_idc)
     if (llp->level_idc == level_idc)
       return llp->level;
   }
-  g_debug ("unsupported level_idc value");
+  GST_DEBUG ("unsupported level_idc value");
   return (GstVaapiLevelH264) 0;
 }
 
@@ -322,7 +331,7 @@ not_found:
 const gchar *
 gst_vaapi_utils_h264_get_level_string (GstVaapiLevelH264 level)
 {
-  if (level < GST_VAAPI_LEVEL_H264_L1 || level > GST_VAAPI_LEVEL_H264_L5_2)
+  if (level < GST_VAAPI_LEVEL_H264_L1 || level > GST_VAAPI_LEVEL_H264_L6_2)
     return NULL;
   return gst_vaapi_h264_level_map[level - GST_VAAPI_LEVEL_H264_L1].name;
 }
@@ -331,7 +340,7 @@ gst_vaapi_utils_h264_get_level_string (GstVaapiLevelH264 level)
 const GstVaapiH264LevelLimits *
 gst_vaapi_utils_h264_get_level_limits (GstVaapiLevelH264 level)
 {
-  if (level < GST_VAAPI_LEVEL_H264_L1 || level > GST_VAAPI_LEVEL_H264_L5_2)
+  if (level < GST_VAAPI_LEVEL_H264_L1 || level > GST_VAAPI_LEVEL_H264_L6_2)
     return NULL;
   return &gst_vaapi_h264_level_limits[level - GST_VAAPI_LEVEL_H264_L1];
 }
@@ -365,7 +374,7 @@ gst_vaapi_utils_h264_get_chroma_type (guint chroma_format_idc)
       chroma_type = GST_VAAPI_CHROMA_TYPE_YUV444;
       break;
     default:
-      g_debug ("unsupported chroma_format_idc value");
+      GST_DEBUG ("unsupported chroma_format_idc value");
       chroma_type = (GstVaapiChromaType) 0;
       break;
   }
@@ -392,7 +401,7 @@ gst_vaapi_utils_h264_get_chroma_format_idc (GstVaapiChromaType chroma_type)
       chroma_format_idc = 3;
       break;
     default:
-      g_debug ("unsupported GstVaapiChromaType value");
+      GST_DEBUG ("unsupported GstVaapiChromaType value");
       chroma_format_idc = 1;
       break;
   }
