@@ -42,7 +42,7 @@ G_BEGIN_DECLS
  * GST_VAAPI_WINDOW_XWINDOW:
  * @window: a #GstVaapiWindow
  *
- * Macro that evaluates to the underlying X11 #Window of @window
+ * Macro that evaluates to the underlying X11 Window of @window
  */
 #define GST_VAAPI_WINDOW_XWINDOW(window) \
     gst_vaapi_window_x11_get_xid (GST_VAAPI_WINDOW_X11 (window))
@@ -64,6 +64,8 @@ gst_vaapi_window_x11_get_xid (GstVaapiWindowX11 * window);
 gboolean
 gst_vaapi_window_x11_is_foreign_xid (GstVaapiWindowX11 * window);
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstVaapiWindowX11, gst_object_unref)
+
 G_END_DECLS
 
 #endif /* GST_VAAPI_WINDOW_X11_H */
