@@ -122,7 +122,7 @@ prop_value_free (PropValue * prop_value)
     g_param_spec_unref (prop_value->pspec);
     prop_value->pspec = NULL;
   }
-  g_slice_free (PropValue, prop_value);
+  g_free (prop_value);
 }
 
 static PropValue *
@@ -133,7 +133,7 @@ prop_value_new_entry (guint id, GParamSpec * pspec, const GValue * value)
   if (!pspec)
     return NULL;
 
-  prop_value = g_slice_new0 (PropValue);
+  prop_value = g_new0 (PropValue, 1);
   if (!prop_value)
     return NULL;
 
@@ -557,26 +557,11 @@ set_codec_state (GstVaapiEncode * encode, GstVideoCodecState * state)
   return TRUE;
 }
 
-static gboolean
-gst_vaapiencode_drain (GstVaapiEncode * encode)
-{
-  GstVaapiEncoderStatus status;
-
-  if (!encode->encoder)
-    return TRUE;
-
-  status = gst_vaapi_encoder_flush (encode->encoder);
-  if (status != GST_VAAPI_ENCODER_STATUS_SUCCESS)
-    return FALSE;
-  gst_vaapiencode_purge (encode);
-
-  return TRUE;
-}
-
 static gboolean
 gst_vaapiencode_set_format (GstVideoEncoder * venc, GstVideoCodecState * state)
 {
   GstVaapiEncode *const encode = GST_VAAPIENCODE_CAST (venc);
+  GstVaapiEncoderStatus status;
 
   g_return_val_if_fail (state->caps != NULL, FALSE);
 
@@ -587,9 +572,14 @@ gst_vaapiencode_set_format (GstVideoEncoder * venc, GstVideoCodecState * state)
           state->caps, NULL))
     return FALSE;
 
-  if (!gst_vaapiencode_drain (encode))
+  GST_VIDEO_ENCODER_STREAM_UNLOCK (encode);
+  status = gst_vaapi_encoder_flush (encode->encoder);
+  GST_VIDEO_ENCODER_STREAM_LOCK (encode);
+  if (status != GST_VAAPI_ENCODER_STATUS_SUCCESS)
     return FALSE;
 
+  gst_vaapiencode_purge (encode);
+
   if (encode->input_state)
     gst_video_codec_state_unref (encode->input_state);
   encode->input_state = gst_video_codec_state_ref (state);
@@ -722,10 +712,12 @@ gst_vaapiencode_finish (GstVideoEncoder * venc)
   if (!encode->encoder)
     return GST_FLOW_NOT_NEGOTIATED;
 
+  GST_VIDEO_ENCODER_STREAM_UNLOCK (encode);
+
   status = gst_vaapi_encoder_flush (encode->encoder);
 
-  GST_VIDEO_ENCODER_STREAM_UNLOCK (encode);
   gst_pad_stop_task (GST_VAAPI_PLUGIN_BASE_SRC_PAD (encode));
+
   GST_VIDEO_ENCODER_STREAM_LOCK (encode);
 
   while (status == GST_VAAPI_ENCODER_STATUS_SUCCESS && ret == GST_FLOW_OK)
@@ -740,13 +732,19 @@ static GstStateChangeReturn
 gst_vaapiencode_change_state (GstElement * element, GstStateChange transition)
 {
   GstVaapiEncode *const encode = GST_VAAPIENCODE_CAST (element);
+  GstVaapiEncoderStatus status;
 
   switch (transition) {
     case GST_STATE_CHANGE_PAUSED_TO_READY:
       gst_pad_stop_task (GST_VAAPI_PLUGIN_BASE_SRC_PAD (encode));
 
-      if (!gst_vaapiencode_drain (encode))
-        goto drain_error;
+      status = gst_vaapi_encoder_flush (encode->encoder);
+      if (status != GST_VAAPI_ENCODER_STATUS_SUCCESS)
+        goto flush_error;
+
+      GST_VIDEO_ENCODER_STREAM_LOCK (encode);
+      gst_vaapiencode_purge (encode);
+      GST_VIDEO_ENCODER_STREAM_UNLOCK (encode);
       break;
     default:
       break;
@@ -755,9 +753,9 @@ gst_vaapiencode_change_state (GstElement * element, GstStateChange transition)
       GST_ELEMENT_CLASS (gst_vaapiencode_parent_class)->change_state (element,
       transition);
 
-drain_error:
+flush_error:
   {
-    GST_ERROR ("failed to drain pending encoded frames");
+    GST_ERROR ("failed to flush pending encoded frames");
     return GST_STATE_CHANGE_FAILURE;
   }
 }
@@ -803,15 +801,21 @@ static gboolean
 gst_vaapiencode_flush (GstVideoEncoder * venc)
 {
   GstVaapiEncode *const encode = GST_VAAPIENCODE_CAST (venc);
+  GstVaapiEncoderStatus status;
 
   if (!encode->encoder)
     return FALSE;
 
   GST_LOG_OBJECT (encode, "flushing");
 
-  if (!gst_vaapiencode_drain (encode))
+  GST_VIDEO_ENCODER_STREAM_UNLOCK (encode);
+  status = gst_vaapi_encoder_flush (encode->encoder);
+  GST_VIDEO_ENCODER_STREAM_LOCK (encode);
+  if (status != GST_VAAPI_ENCODER_STATUS_SUCCESS)
     return FALSE;
 
+  gst_vaapiencode_purge (encode);
+
   gst_vaapi_encoder_replace (&encode->encoder, NULL);
   if (!ensure_encoder (encode))
     return FALSE;
