@@ -26,12 +26,11 @@
  *
  * Encodes raw video streams into HEVC bitstreams.
  *
- * <refsect2>
- * <title>Example launch line</title>
+ * ## Example launch line
+ *
  * |[
  *  gst-launch-1.0 -ev videotestsrc num-buffers=60 ! timeoverlay ! vaapih265enc ! h265parse ! matroskamux ! filesink location=test.mkv
  * ]|
- * </refsect2>
  */
 
 #include "gstcompat.h"
@@ -53,43 +52,16 @@ GST_DEBUG_CATEGORY_STATIC (gst_vaapi_h265_encode_debug);
   "stream-format = (string) { hvc1, byte-stream }, " \
   "alignment = (string) au"
 
-/* *INDENT-OFF* */
-static const char gst_vaapiencode_h265_sink_caps_str[] =
-  GST_VAAPI_MAKE_SURFACE_CAPS ", "
-  GST_CAPS_INTERLACED_FALSE "; "
-  GST_VIDEO_CAPS_MAKE (GST_VIDEO_FORMATS_ALL) ", "
-  GST_CAPS_INTERLACED_FALSE;
-/* *INDENT-ON* */
-
-/* *INDENT-OFF* */
-static const char gst_vaapiencode_h265_src_caps_str[] =
-  GST_CODEC_CAPS ", "
-  "profile = (string) { main, main-10 }";
-/* *INDENT-ON* */
-
-/* *INDENT-OFF* */
-static GstStaticPadTemplate gst_vaapiencode_h265_sink_factory =
-  GST_STATIC_PAD_TEMPLATE ("sink",
-      GST_PAD_SINK,
-      GST_PAD_ALWAYS,
-      GST_STATIC_CAPS (gst_vaapiencode_h265_sink_caps_str));
-/* *INDENT-ON* */
-
-/* *INDENT-OFF* */
-static GstStaticPadTemplate gst_vaapiencode_h265_src_factory =
-  GST_STATIC_PAD_TEMPLATE ("src",
-      GST_PAD_SRC,
-      GST_PAD_ALWAYS,
-      GST_STATIC_CAPS (gst_vaapiencode_h265_src_caps_str));
-/* *INDENT-ON* */
+#define EXTRA_FORMATS {}
 
 /* h265 encode */
-G_DEFINE_TYPE (GstVaapiEncodeH265, gst_vaapiencode_h265, GST_TYPE_VAAPIENCODE);
+GST_VAAPI_ENCODE_REGISTER_TYPE (h265, H265, H265, EXTRA_FORMATS,
+    gst_vaapi_utils_h265_get_profile_string);
 
 static void
 gst_vaapiencode_h265_init (GstVaapiEncodeH265 * encode)
 {
-  gst_vaapiencode_init_properties (GST_VAAPIENCODE_CAST (encode));
+  /* nothing to do here */
 }
 
 static void
@@ -98,109 +70,12 @@ gst_vaapiencode_h265_finalize (GObject * object)
   G_OBJECT_CLASS (gst_vaapiencode_h265_parent_class)->finalize (object);
 }
 
-static void
-gst_vaapiencode_h265_set_property (GObject * object,
-    guint prop_id, const GValue * value, GParamSpec * pspec)
+static GArray *
+gst_vaapiencode_h265_get_allowed_profiles (GstVaapiEncode * encode,
+    GstCaps * allowed)
 {
-  GstVaapiEncodeClass *const encode_class = GST_VAAPIENCODE_GET_CLASS (object);
-  GstVaapiEncode *const base_encode = GST_VAAPIENCODE_CAST (object);
-
-  switch (prop_id) {
-    default:
-      if (!encode_class->set_property (base_encode, prop_id, value))
-        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-      break;
-  }
-}
-
-static void
-gst_vaapiencode_h265_get_property (GObject * object,
-    guint prop_id, GValue * value, GParamSpec * pspec)
-{
-  GstVaapiEncodeClass *const encode_class = GST_VAAPIENCODE_GET_CLASS (object);
-  GstVaapiEncode *const base_encode = GST_VAAPIENCODE_CAST (object);
-
-  switch (prop_id) {
-    default:
-      if (!encode_class->get_property (base_encode, prop_id, value))
-        G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-      break;
-  }
-}
-
-static GstVaapiProfile
-gst_vaapiencode_h265_get_profile (GstCaps * caps)
-{
-  guint i;
-
-  for (i = 0; i < gst_caps_get_size (caps); i++) {
-    GstStructure *const structure = gst_caps_get_structure (caps, i);
-    const GValue *const value = gst_structure_get_value (structure, "profile");
-
-    if (value && G_VALUE_HOLDS_STRING (value)) {
-      const gchar *str = g_value_get_string (value);
-      if (str)
-        return gst_vaapi_utils_h265_get_profile_from_string (str);
-    }
-  }
-
-  return GST_VAAPI_PROFILE_UNKNOWN;
-}
-
-typedef struct
-{
-  GstVaapiProfile best_profile;
-  guint best_score;
-} FindBestProfileData;
-
-static void
-find_best_profile_value (FindBestProfileData * data, const GValue * value)
-{
-  const gchar *str;
-  GstVaapiProfile profile;
-  guint score;
-
-  if (!value || !G_VALUE_HOLDS_STRING (value))
-    return;
-
-  str = g_value_get_string (value);
-  if (!str)
-    return;
-  profile = gst_vaapi_utils_h265_get_profile_from_string (str);
-  if (!profile)
-    return;
-  score = gst_vaapi_utils_h265_get_profile_score (profile);
-  if (score < data->best_score)
-    return;
-  data->best_profile = profile;
-  data->best_score = score;
-}
-
-static GstVaapiProfile
-find_best_profile (GstCaps * caps)
-{
-  FindBestProfileData data;
-  guint i, j, num_structures, num_values;
-
-  data.best_profile = GST_VAAPI_PROFILE_UNKNOWN;
-  data.best_score = 0;
-
-  num_structures = gst_caps_get_size (caps);
-  for (i = 0; i < num_structures; i++) {
-    GstStructure *const structure = gst_caps_get_structure (caps, i);
-    const GValue *const value = gst_structure_get_value (structure, "profile");
-
-    if (!value)
-      continue;
-    if (G_VALUE_HOLDS_STRING (value))
-      find_best_profile_value (&data, value);
-    else if (GST_VALUE_HOLDS_LIST (value)) {
-      num_values = gst_value_list_get_size (value);
-      for (j = 0; j < num_values; j++)
-        find_best_profile_value (&data, gst_value_list_get_value (value, j));
-    }
-  }
-  return data.best_profile;
+  return gst_vaapi_encoder_get_profiles_from_caps (allowed,
+      gst_vaapi_utils_h265_get_profile_from_string);
 }
 
 static gboolean
@@ -208,31 +83,90 @@ gst_vaapiencode_h265_set_config (GstVaapiEncode * base_encode)
 {
   GstVaapiEncoderH265 *const encoder =
       GST_VAAPI_ENCODER_H265 (base_encode->encoder);
-  GstCaps *allowed_caps;
+  GstCaps *allowed_caps = NULL;
+  GstCaps *template_caps = NULL;
+  GArray *profiles = NULL;
+  GArray *profiles_hw = NULL;
+  GArray *profiles_allowed = NULL;
   GstVaapiProfile profile;
+  gboolean ret = TRUE;
+  guint i, j;
 
-  /* Check for the largest profile that is supported */
+  profiles_hw = gst_vaapi_display_get_encode_profiles_by_codec
+      (GST_VAAPI_PLUGIN_BASE_DISPLAY (base_encode), GST_VAAPI_CODEC_H265);
+  if (!profiles_hw) {
+    ret = FALSE;
+    goto out;
+  }
+
+  template_caps =
+      gst_pad_get_pad_template_caps (GST_VAAPI_PLUGIN_BASE_SRC_PAD
+      (base_encode));
   allowed_caps =
       gst_pad_get_allowed_caps (GST_VAAPI_PLUGIN_BASE_SRC_PAD (base_encode));
-  if (!allowed_caps)
-    return TRUE;
-
-  profile = find_best_profile (allowed_caps);
-  gst_caps_unref (allowed_caps);
-  if (profile) {
-    GST_INFO ("using %s profile as target decoder constraints",
-        gst_vaapi_utils_h265_get_profile_string (profile));
-    if (!gst_vaapi_encoder_h265_set_max_profile (encoder, profile))
-      return FALSE;
+  if (!allowed_caps || allowed_caps == template_caps) {
+    ret = gst_vaapi_encoder_h265_set_allowed_profiles (encoder, profiles_hw);
+    goto out;
+  } else if (gst_caps_is_empty (allowed_caps)) {
+    ret = FALSE;
+    goto out;
   }
-  return TRUE;
+
+  profiles = gst_vaapi_encoder_get_profiles_from_caps (allowed_caps,
+      gst_vaapi_utils_h265_get_profile_from_string);
+  if (!profiles) {
+    ret = FALSE;
+    goto out;
+  }
+
+  profiles_allowed = g_array_new (FALSE, FALSE, sizeof (GstVaapiProfile));
+  if (!profiles_allowed) {
+    ret = FALSE;
+    goto out;
+  }
+
+  for (i = 0; i < profiles->len; i++) {
+    profile = g_array_index (profiles, GstVaapiProfile, i);
+    for (j = 0; j < profiles_hw->len; j++) {
+      GstVaapiProfile p = g_array_index (profiles_hw, GstVaapiProfile, j);
+      if (p == profile) {
+        g_array_append_val (profiles_allowed, profile);
+        break;
+      }
+    }
+  }
+  if (profiles_allowed->len == 0) {
+    ret = FALSE;
+    goto out;
+  }
+
+  ret = gst_vaapi_encoder_h265_set_allowed_profiles (encoder, profiles_allowed);
+
+out:
+  if (allowed_caps)
+    gst_caps_unref (allowed_caps);
+  if (template_caps)
+    gst_caps_unref (template_caps);
+  if (profiles)
+    g_array_unref (profiles);
+  if (profiles_hw)
+    g_array_unref (profiles_hw);
+  if (profiles_allowed)
+    g_array_unref (profiles_allowed);
+
+  return ret;
 }
 
 static GstCaps *
 gst_vaapiencode_h265_get_caps (GstVaapiEncode * base_encode)
 {
   GstVaapiEncodeH265 *const encode = GST_VAAPIENCODE_H265_CAST (base_encode);
+  GstVaapiEncoderH265 *const encoder =
+      GST_VAAPI_ENCODER_H265 (base_encode->encoder);
   GstCaps *caps, *allowed_caps;
+  GstVaapiProfile profile = GST_VAAPI_PROFILE_UNKNOWN;
+  GstVaapiLevelH265 level = 0;
+  GstVaapiTierH265 tier = GST_VAAPI_TIER_H265_UNKNOWN;
 
   caps = gst_caps_from_string (GST_CODEC_CAPS);
 
@@ -260,7 +194,22 @@ gst_vaapiencode_h265_get_caps (GstVaapiEncode * base_encode)
 
   base_encode->need_codec_data = encode->is_hvc;
 
-  /* XXX: update profile and level information */
+  gst_vaapi_encoder_h265_get_profile_tier_level (encoder,
+      &profile, &tier, &level);
+  if (profile != GST_VAAPI_PROFILE_UNKNOWN) {
+    gst_caps_set_simple (caps, "profile", G_TYPE_STRING,
+        gst_vaapi_utils_h265_get_profile_string (profile), NULL);
+
+    if (level) {
+      gst_caps_set_simple (caps, "level", G_TYPE_STRING,
+          gst_vaapi_utils_h265_get_level_string (level), NULL);
+
+      if (tier != GST_VAAPI_TIER_H265_UNKNOWN)
+        gst_caps_set_simple (caps, "tier", G_TYPE_STRING,
+            gst_vaapi_utils_h265_get_tier_string (tier), NULL);
+    }
+  }
+
   return caps;
 }
 
@@ -401,21 +350,23 @@ error_convert_buffer:
 }
 
 static void
-gst_vaapiencode_h265_class_init (GstVaapiEncodeH265Class * klass)
+gst_vaapiencode_h265_class_init (GstVaapiEncodeH265Class * klass, gpointer data)
 {
   GObjectClass *const object_class = G_OBJECT_CLASS (klass);
   GstElementClass *const element_class = GST_ELEMENT_CLASS (klass);
   GstVaapiEncodeClass *const encode_class = GST_VAAPIENCODE_CLASS (klass);
-
-  GST_DEBUG_CATEGORY_INIT (gst_vaapi_h265_encode_debug,
-      GST_PLUGIN_NAME, 0, GST_PLUGIN_DESC);
+  GstCaps *sink_caps = ((GstVaapiEncodeInitData *) data)->sink_caps;
+  GstCaps *src_caps = ((GstVaapiEncodeInitData *) data)->src_caps;
+  GstPadTemplate *templ;
+  GstCaps *static_caps;
+  gpointer encoder_class;
 
   object_class->finalize = gst_vaapiencode_h265_finalize;
-  object_class->set_property = gst_vaapiencode_h265_set_property;
-  object_class->get_property = gst_vaapiencode_h265_get_property;
+  object_class->set_property = gst_vaapiencode_set_property_subclass;
+  object_class->get_property = gst_vaapiencode_get_property_subclass;
 
-  encode_class->get_properties = gst_vaapi_encoder_h265_get_default_properties;
-  encode_class->get_profile = gst_vaapiencode_h265_get_profile;
+  encode_class->get_allowed_profiles =
+      gst_vaapiencode_h265_get_allowed_profiles;
   encode_class->set_config = gst_vaapiencode_h265_set_config;
   encode_class->get_caps = gst_vaapiencode_h265_get_caps;
   encode_class->alloc_encoder = gst_vaapiencode_h265_alloc_encoder;
@@ -428,12 +379,26 @@ gst_vaapiencode_h265_class_init (GstVaapiEncodeH265Class * klass)
       "Sreerenj Balachandran <sreerenj.balachandran@intel.com>");
 
   /* sink pad */
-  gst_element_class_add_static_pad_template (element_class,
-      &gst_vaapiencode_h265_sink_factory);
+  g_assert (sink_caps);
+  static_caps = gst_caps_from_string (GST_VAAPI_ENCODE_STATIC_SINK_CAPS);
+  templ =
+      gst_pad_template_new ("sink", GST_PAD_SINK, GST_PAD_ALWAYS, sink_caps);
+  gst_pad_template_set_documentation_caps (templ, static_caps);
+  gst_element_class_add_pad_template (element_class, templ);
+  gst_caps_unref (static_caps);
+  gst_caps_unref (sink_caps);
 
   /* src pad */
-  gst_element_class_add_static_pad_template (element_class,
-      &gst_vaapiencode_h265_src_factory);
+  g_assert (src_caps);
+  static_caps = gst_caps_from_string (GST_CODEC_CAPS);
+  templ = gst_pad_template_new ("src", GST_PAD_SRC, GST_PAD_ALWAYS, src_caps);
+  gst_pad_template_set_documentation_caps (templ, static_caps);
+  gst_element_class_add_pad_template (element_class, templ);
+  gst_caps_unref (static_caps);
+  gst_caps_unref (src_caps);
 
-  gst_vaapiencode_class_init_properties (encode_class);
+  encoder_class = g_type_class_ref (GST_TYPE_VAAPI_ENCODER_H265);
+  g_assert (encoder_class);
+  gst_vaapiencode_class_install_properties (encode_class, encoder_class);
+  g_type_class_unref (encoder_class);
 }
