@@ -361,7 +361,7 @@ gst_vaapi_video_memory_new (GstAllocator * base_allocator,
 
   g_return_val_if_fail (GST_VAAPI_IS_VIDEO_ALLOCATOR (allocator), NULL);
 
-  mem = g_slice_new (GstVaapiVideoMemory);
+  mem = g_new (GstVaapiVideoMemory, 1);
   if (!mem)
     return NULL;
 
@@ -620,7 +620,7 @@ gst_vaapi_video_allocator_free (GstAllocator * allocator, GstMemory * base_mem)
   gst_vaapi_surface_proxy_replace (&mem->proxy, NULL);
   gst_vaapi_video_meta_replace (&mem->meta, NULL);
   g_mutex_clear (&mem->lock);
-  g_slice_free (GstVaapiVideoMemory, mem);
+  g_free (mem);
 }
 
 static void
@@ -1255,32 +1255,6 @@ gst_vaapi_video_info_quark_get (void)
   return g_quark;
 }
 
-#define ALLOCATION_VINFO_QUARK allocation_vinfo_quark_get ()
-static GQuark
-allocation_vinfo_quark_get (void)
-{
-  static gsize g_quark;
-
-  if (g_once_init_enter (&g_quark)) {
-    gsize quark = (gsize) g_quark_from_static_string ("allocation-vinfo");
-    g_once_init_leave (&g_quark, quark);
-  }
-  return g_quark;
-}
-
-#define SURFACE_ALLOC_FLAGS_QUARK surface_alloc_flags_quark_get ()
-static GQuark
-surface_alloc_flags_quark_get (void)
-{
-  static gsize g_quark;
-
-  if (g_once_init_enter (&g_quark)) {
-    gsize quark = (gsize) g_quark_from_static_string ("surface-alloc-flags");
-    g_once_init_leave (&g_quark, quark);
-  }
-  return g_quark;
-}
-
 #define NEGOTIATED_VINFO_QUARK negotiated_vinfo_quark_get ()
 static GQuark
 negotiated_vinfo_quark_get (void)
@@ -1323,13 +1297,13 @@ gst_allocator_get_vaapi_video_info (GstAllocator * allocator,
     return NULL;
 
   if (out_flags_ptr) {
-    value = gst_structure_id_get_value (structure, SURFACE_ALLOC_FLAGS_QUARK);
+    value = gst_structure_get_value (structure, "surface-alloc-flags");
     if (!value)
       return NULL;
     *out_flags_ptr = g_value_get_uint (value);
   }
 
-  value = gst_structure_id_get_value (structure, ALLOCATION_VINFO_QUARK);
+  value = gst_structure_get_value (structure, "allocation-vinfo");
   if (!value)
     return NULL;
   return g_value_get_boxed (value);
@@ -1355,9 +1329,9 @@ gst_allocator_set_vaapi_video_info (GstAllocator * allocator,
   g_return_val_if_fail (alloc_info != NULL, FALSE);
 
   g_object_set_qdata_full (G_OBJECT (allocator), GST_VAAPI_VIDEO_INFO_QUARK,
-      gst_structure_new_id (GST_VAAPI_VIDEO_INFO_QUARK,
-          ALLOCATION_VINFO_QUARK, GST_TYPE_VIDEO_INFO, alloc_info,
-          SURFACE_ALLOC_FLAGS_QUARK, G_TYPE_UINT, surface_alloc_flags, NULL),
+      gst_structure_new_static_str ("GstVaapiVideoInfo",
+          "allocation-vinfo", GST_TYPE_VIDEO_INFO, alloc_info,
+          "surface-alloc-flags", G_TYPE_UINT, surface_alloc_flags, NULL),
       (GDestroyNotify) gst_structure_free);
 
   return TRUE;
